@@ -2,7 +2,7 @@
 #
 # Python 2/3 compatibility functions for XlsxWriter.
 #
-# Copyright (c), 2013-2015, John McNamara, jmcnamara@cpan.org
+# Copyright (c), 2013-2018, John McNamara, jmcnamara@cpan.org
 #
 
 import sys
@@ -31,9 +31,11 @@ except ImportError:
 
 # Types to check in Python 2/3.
 if sys.version_info[0] == 2:
+    int_types = (int, long)
     num_types = (float, int, long, Decimal, Fraction)
     str_types = basestring
 else:
+    int_types = (int)
     num_types = (float, int, Decimal, Fraction)
     str_types = str
 
@@ -42,3 +44,11 @@ if sys.version_info < (2, 6, 0):
     from StringIO import StringIO as BytesIO
 else:
     from io import BytesIO as BytesIO
+
+
+def force_unicode(string):
+    """Return string as a native string"""
+    if sys.version_info[0] == 2:
+        if isinstance(string, unicode):
+            return string.encode('utf-8')
+    return string
