@@ -2,7 +2,7 @@
 #
 # ContentTypes - A class for writing the Excel XLSX ContentTypes file.
 #
-# Copyright 2013-2015, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2018, John McNamara, jmcnamara@cpan.org
 #
 
 import copy
@@ -130,7 +130,12 @@ class ContentTypes(xmlwriter.XMLwriter):
     def _add_image_types(self, image_types):
         # Add the image default types.
         for image_type in image_types:
-            self._add_default((image_type, 'image/' + image_type))
+            extension = image_type
+
+            if image_type in ('wmf', 'emf'):
+                image_type = 'x-' + image_type
+
+            self._add_default((extension, 'image/' + image_type))
 
     def _add_table_name(self, table_name):
         # Add the name of a table to the ContentTypes overrides.
@@ -150,6 +155,11 @@ class ContentTypes(xmlwriter.XMLwriter):
 
         self._add_default(('bin', 'application/vnd.ms-office.vbaProject'))
 
+    def _add_custom_properties(self):
+        # Add the custom properties to the ContentTypes overrides.
+        self._add_override(('/docProps/custom.xml',
+                           app_document + 'custom-properties+xml'))
+
     ###########################################################################
     #
     # XML methods.
