@@ -2,11 +2,12 @@
 #
 # Format - A class for writing the Excel XLSX Worksheet file.
 #
-# Copyright 2013-2015, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2018, John McNamara, jmcnamara@cpan.org
 #
 
 # Package imports.
 from . import xmlwriter
+from warnings import warn
 
 
 class Format(xmlwriter.XMLwriter):
@@ -22,11 +23,13 @@ class Format(xmlwriter.XMLwriter):
     #
     ###########################################################################
 
-    def __init__(self, properties={}, xf_indices=None, dxf_indices=None):
+    def __init__(self, properties=None, xf_indices=None, dxf_indices=None):
         """
         Constructor.
 
         """
+        if properties is None:
+            properties = {}
 
         super(Format, self).__init__()
 
@@ -57,7 +60,8 @@ class Format(xmlwriter.XMLwriter):
         self.font_condense = 0
         self.font_extend = 0
         self.theme = 0
-        self.hyperlink = 0
+        self.hyperlink = False
+        self.xf_id = 0
 
         self.hidden = 0
         self.locked = 1
@@ -67,7 +71,6 @@ class Format(xmlwriter.XMLwriter):
         self.text_v_align = 0
         self.text_justlast = 0
         self.rotation = 0
-        self.center_across = 0
 
         self.fg_color = 0
         self.bg_color = 0
@@ -106,6 +109,8 @@ class Format(xmlwriter.XMLwriter):
         for key, value in properties.items():
             getattr(self, 'set_' + key)(value)
 
+        self._format_key = None
+
     ###########################################################################
     #
     # Format properties.
@@ -152,12 +157,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.font_color = self._get_color(font_color)
 
-    def set_bold(self, bold=1):
+    def set_bold(self, bold=True):
         """
         Set the Format bold property.
 
         Args:
-            bold: Default is 1, turns property on.
+            bold: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -165,12 +170,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.bold = bold
 
-    def set_italic(self, italic=1):
+    def set_italic(self, italic=True):
         """
         Set the Format italic property.
 
         Args:
-            italic: Default is 1, turns property on.
+            italic: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -191,12 +196,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.underline = underline
 
-    def set_font_strikeout(self, font_strikeout=1):
+    def set_font_strikeout(self, font_strikeout=True):
         """
         Set the Format font_strikeout property.
 
         Args:
-            font_strikeout: Default is 1, turns property on.
+            font_strikeout: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -217,12 +222,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.font_script = font_script
 
-    def set_font_outline(self, font_outline=1):
+    def set_font_outline(self, font_outline=True):
         """
         Set the Format font_outline property.
 
         Args:
-            font_outline: Default is 1, turns property on.
+            font_outline: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -230,12 +235,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.font_outline = font_outline
 
-    def set_font_shadow(self, font_shadow=1):
+    def set_font_shadow(self, font_shadow=True):
         """
         Set the Format font_shadow property.
 
         Args:
-            font_shadow: Default is 1, turns property on.
+            font_shadow: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -256,12 +261,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.num_format = num_format
 
-    def set_locked(self, locked=1):
+    def set_locked(self, locked=True):
         """
         Set the Format locked property.
 
         Args:
-            locked: Default is 1, turns property on.
+            locked: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -269,12 +274,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.locked = locked
 
-    def set_hidden(self, hidden=1):
+    def set_hidden(self, hidden=True):
         """
         Set the Format hidden property.
 
         Args:
-            hidden: Default is 1, turns property on.
+            hidden: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -333,25 +338,22 @@ class Format(xmlwriter.XMLwriter):
         if alignment == 'vdistributed':
             self.set_text_v_align(5)
 
-    def set_center_across(self, center_across=1):
+    def set_center_across(self, align_type=None):
         """
         Set the Format center_across property.
 
-        Args:
-            center_across: Default is 1, turns property on.
-
         Returns:
             Nothing.
 
         """
-        self.center_across = center_across
+        self.set_text_h_align(6)
 
-    def set_text_wrap(self, text_wrap=1):
+    def set_text_wrap(self, text_wrap=True):
         """
         Set the Format text_wrap property.
 
         Args:
-            text_wrap: Default is 1, turns property on.
+            text_wrap: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -375,12 +377,12 @@ class Format(xmlwriter.XMLwriter):
         # Map user angle to Excel angle.
         if rotation == 270:
             rotation = 255
-        elif rotation >= -90 or rotation <= 90:
+        elif -90 <= rotation <= 90:
             if rotation < 0:
                 rotation = -rotation + 90
         else:
-            raise Exception(
-                "Rotation rotation outside range: -90 <= angle <= 90")
+            warn("Rotation rotation outside range: -90 <= angle <= 90")
+            return
 
         self.rotation = rotation
 
@@ -389,7 +391,7 @@ class Format(xmlwriter.XMLwriter):
         Set the Format indent property.
 
         Args:
-            indent: Default is 1, turns property on.
+            indent: Default is 1, first indentation level.
 
         Returns:
             Nothing.
@@ -397,12 +399,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.indent = indent
 
-    def set_shrink(self, shrink=1):
+    def set_shrink(self, shrink=True):
         """
         Set the Format shrink property.
 
         Args:
-            shrink: Default is 1, turns property on.
+            shrink: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -410,12 +412,12 @@ class Format(xmlwriter.XMLwriter):
         """
         self.shrink = shrink
 
-    def set_text_justlast(self, text_justlast=1):
+    def set_text_justlast(self, text_justlast=True):
         """
         Set the Format text_justlast property.
 
         Args:
-            text_justlast: Default is 1, turns property on.
+            text_justlast: Default is True, turns property on.
 
         Returns:
             Nothing.
@@ -441,7 +443,7 @@ class Format(xmlwriter.XMLwriter):
         Set the Format bg_color property.
 
         Args:
-            bg_color: Background colour. No default.
+            bg_color: Background color. No default.
 
         Returns:
             Nothing.
@@ -454,7 +456,7 @@ class Format(xmlwriter.XMLwriter):
         Set the Format fg_color property.
 
         Args:
-            fg_color: Foreground colour. No default.
+            fg_color: Foreground color. No default.
 
         Returns:
             Nothing.
@@ -646,11 +648,11 @@ class Format(xmlwriter.XMLwriter):
     #
     ###########################################################################
 
-    def set_has_font(self, has_font=1):
+    def set_has_font(self, has_font=True):
         # Set the has_font property.
         self.has_font = has_font
 
-    def set_has_fill(self, has_fill=1):
+    def set_has_fill(self, has_fill=True):
         # Set the has_fill property.
         self.has_fill = has_fill
 
@@ -678,9 +680,9 @@ class Format(xmlwriter.XMLwriter):
         # Set the text_v_align property.
         self.text_v_align = text_v_align
 
-    def set_reading_order(self, reading_order=1):
+    def set_reading_order(self, direction=0):
         # Set the reading_order property.
-        self.reading_order = reading_order
+        self.reading_order = direction
 
     def set_valign(self, align):
         # Set vertical cell alignment. This is required by the constructor
@@ -690,7 +692,6 @@ class Format(xmlwriter.XMLwriter):
 
     def set_font_family(self, font_family):
         # Set the Format font_family property.
-
         self.font_family = font_family
 
     def set_font_charset(self, font_charset):
@@ -713,13 +714,12 @@ class Format(xmlwriter.XMLwriter):
         # Set the Format theme property.
         self.theme = theme
 
-    def set_hyperlink(self, hyperlink=1):
-        # Set the properties for the hyperlink style. This doesn't
-        # currently work. To be fixed when styles are supported.
-
+    def set_hyperlink(self, hyperlink=True):
+        # Set the properties for the hyperlink style. This isn't
+        # currently public. To be fixed when styles are supported.
+        self.xf_id = 1
         self.set_underline(1)
         self.set_theme(10)
-        self.set_align('top')
         self.hyperlink = hyperlink
 
     def set_color_indexed(self, color_index):
@@ -846,16 +846,17 @@ class Format(xmlwriter.XMLwriter):
 
     def _get_format_key(self):
         # Returns a unique hash key for a font. Used by Workbook.
-        key = ':'.join(self._to_string(x) for x in (
-            self._get_font_key(),
-            self._get_border_key(),
-            self._get_fill_key(),
-            self._get_alignment_key(),
-            self.num_format,
-            self.locked,
-            self.hidden))
+        if self._format_key is None:
+            self._format_key = ':'.join(self._to_string(x) for x in (
+                self._get_font_key(),
+                self._get_border_key(),
+                self._get_fill_key(),
+                self._get_alignment_key(),
+                self.num_format,
+                self.locked,
+                self.hidden))
 
-        return key
+        return self._format_key
 
     def _get_font_key(self):
         # Returns a unique hash key for a font. Used by Workbook.
@@ -871,7 +872,8 @@ class Format(xmlwriter.XMLwriter):
             self.font_name,
             self.italic,
             self.font_size,
-            self.underline))
+            self.underline,
+            self.theme))
 
         return key
 
@@ -956,7 +958,7 @@ class Format(xmlwriter.XMLwriter):
 
     def _get_color(self, color):
         # Used in conjunction with the set_xxx_color methods to convert a
-        # colour name into an RGB formatted string. These colours are for
+        # color name into an RGB formatted string. These colors are for
         # backward compatibility with older versions of Excel.
         named_colors = {
             'black': '#000000',
